datastructuretools.StatalServer
===============================

.. abjad-lineage:: abjad.tools.datastructuretools.StatalServer.StatalServer

.. autoclass:: abjad.tools.datastructuretools.StatalServer.StatalServer

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.StatalServer.StatalServer.cyclic_tree
      ~abjad.tools.datastructuretools.StatalServer.StatalServer.last_node
      ~abjad.tools.datastructuretools.StatalServer.StatalServer.__call__
      ~abjad.tools.datastructuretools.StatalServer.StatalServer.__eq__
      ~abjad.tools.datastructuretools.StatalServer.StatalServer.__format__
      ~abjad.tools.datastructuretools.StatalServer.StatalServer.__ne__
      ~abjad.tools.datastructuretools.StatalServer.StatalServer.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.StatalServer.StatalServer.cyclic_tree
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.StatalServer.StatalServer.last_node
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.StatalServer.StatalServer.__call__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.StatalServer.StatalServer.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.StatalServer.StatalServer.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.StatalServer.StatalServer.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.StatalServer.StatalServer.__repr__
   :noindex:
